@@ -25,7 +25,9 @@ from scaleway_core.utils.waiter import (
 from scaleway_core.bridge import (
     Money,
     Region,
+    ALL_REGIONS,
     Zone,
+    ALL_ZONES,
     ScwFile,
     ServiceInfo,
     TimeSeriesPoint,
@@ -43,7 +45,9 @@ __all__ = [
     "WaitForStopCondition",
     "Money",
     "Region",
+    "ALL_REGIONS",
     "Zone",
+    "ALL_ZONES",
     "ScwFile",
     "ServiceInfo",
     "TimeSeriesPoint",
